@@ -6,17 +6,14 @@ dbhatta <- function(x){
 # d: bhattacharyya distance matrix
 #########################################################
 	x <- as.matrix(x)
-	n <- dim(x)[1]
-	p <- dim(x)[2]
-	d <- matrix(0, nrow=n, ncol=n)
-	for (i in 1:(n-1)){
-		for (j in (i+1):n){
-			a <- sqrt(x[i,]*x[j,])
-			a <- sum(a)
-			d[i,j] <- acos(a)
-			d[j,i] <- d[i,j]
-		}
+	aux <- apply(x, 1, sum)
+	if (any(aux != 1))
+	{
+	  stop("Rows must add up to 1.")
 	}
-        d <- as.dist(d)
+	
+	x1 <- sqrt(x)
+	d <- acos(x1%*%t(x1))
+	d <- as.dist(d)
 	return(d)
 }
